==> haskell-regex-applicative-text-0.1.0.1-276-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-regex-applicative-text.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 regex-applicative-text
version:              0.1.0.1
visibility:           public
id:                   regex-applicative-text-0.1.0.1-AguJI8xx1oI9ShRaazcZXX
key:                  regex-applicative-text-0.1.0.1-AguJI8xx1oI9ShRaazcZXX
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/regex-applicative-text#readme
synopsis:             regex-applicative on text
description:          Wrapped regex-applicative primitives to work with Text
category:             Text
abi:                  0d5aab9444cb8c1f941f5b061a9df799
exposed:              True
exposed-modules:      Text.Regex.Applicative.Text
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/regex-applicative-text-0.1.0.1

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/regex-applicative-text-0.1.0.1

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/regex-applicative-text-0.1.0.1

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-regex-applicative-text
hs-libraries:         HSregex-applicative-text-0.1.0.1-AguJI8xx1oI9ShRaazcZXX
depends:
    base-4.17.2.1 regex-applicative-0.3.4-IXUa5E4aM1Y2olN03bouzQ
    text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-regex-applicative-text/html/regex-applicative-text.haddock

haddock-html:         /usr/share/doc/haskell-regex-applicative-text/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-regex-applicative-text-0.1.0.1-277-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-regex-applicative-text.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 regex-applicative-text
version:              0.1.0.1
visibility:           public
id:                   regex-applicative-text-0.1.0.1-JUsYV6G8mElHn53U6eBghm
key:                  regex-applicative-text-0.1.0.1-JUsYV6G8mElHn53U6eBghm
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/regex-applicative-text#readme
synopsis:             regex-applicative on text
description:          Wrapped regex-applicative primitives to work with Text
category:             Text
abi:                  6a0393bb45577581cfde81a07ae6bf2b
exposed:              True
exposed-modules:      Text.Regex.Applicative.Text
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/regex-applicative-text-0.1.0.1

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/regex-applicative-text-0.1.0.1

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/regex-applicative-text-0.1.0.1

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-regex-applicative-text
hs-libraries:         HSregex-applicative-text-0.1.0.1-JUsYV6G8mElHn53U6eBghm
depends:
    base-4.17.2.1 regex-applicative-0.3.4-L0hLivuuEKJ1432NTPHu1d
    text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-regex-applicative-text/html/regex-applicative-text.haddock

haddock-html:         /usr/share/doc/haskell-regex-applicative-text/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
